@@ -1,6 +1,6 @@
-/* Ergo, version 3.8, a program for linear scaling electronic structure
+/* Ergo, version 3.8.2, a program for linear scaling electronic structure
  * calculations.
- * Copyright (C) 2019 Elias Rudberg, Emanuel H. Rubensson, Pawel Salek,
+ * Copyright (C) 2023 Elias Rudberg, Emanuel H. Rubensson, Pawel Salek,
  * and Anastasia Kruchinina.
  * 
  * This program is free software: you can redistribute it and/or modify
@@ -42,7 +42,9 @@
    the TEST_BUILD. 
  */
 
-#define _POSIX_SOURCE 1
+/* ELIAS NOTE 2023-07-17: there was a "#define _POSIX_SOURCE 1" line
+   here which was removed because it caused problems when testing on
+   FreeBSD. */
 
 #define __CVERSION__
 #include <cmath>
