@@ -1,3 +1,6 @@
+#ifndef _yy_defines_h_
+#define _yy_defines_h_
+
 #define NUMBER 257
 #define DOT 258
 #define SYMBOL 259
@@ -37,10 +40,12 @@
 #endif
 #ifndef YYSTYPE_IS_DECLARED
 #define YYSTYPE_IS_DECLARED 1
-typedef union {
+typedef union YYSTYPE {
   double num;     /* for returning numbers */
   char str[256];  /* for returning strings */
   struct variable *var; /* for returning lvalues */
 } YYSTYPE;
 #endif /* !YYSTYPE_IS_DECLARED */
 extern YYSTYPE yylval;
+
+#endif /* _yy_defines_h_ */
