@@ -1,6 +1,6 @@
-/* Ergo, version 3.8, a program for linear scaling electronic structure
+/* Ergo, version 3.8.2, a program for linear scaling electronic structure
  * calculations.
- * Copyright (C) 2019 Elias Rudberg, Emanuel H. Rubensson, Pawel Salek,
+ * Copyright (C) 2023 Elias Rudberg, Emanuel H. Rubensson, Pawel Salek,
  * and Anastasia Kruchinina.
  * 
  * This program is free software: you can redistribute it and/or modify
@@ -271,7 +271,7 @@ int mainFun(int argc,char* argv[]) {
       std::vector<int> permutationVec(size);
       for (int ind = 0; ind < size; ++ind )
 	permutationVec[ind] = ind;
-      std::random_shuffle ( permutationVec.begin(), permutationVec.end() );
+      mat::random_shuffle ( permutationVec.begin(), permutationVec.end() );
       /* Get inverse permutation */
       std::vector<int> inversePermutationVec(size);
       for (int ind = 0; ind < size; ++ind) {
@@ -403,7 +403,7 @@ int mainFun(int argc,char* argv[]) {
       for (int ind = 0; ind < size; ++ind )
 	permutationVec[ind] = ind;
       noPermutationVec = permutationVec;
-      std::random_shuffle ( permutationVec.begin(), permutationVec.end() );
+      mat::random_shuffle ( permutationVec.begin(), permutationVec.end() );
       /* Get inverse permutation */
       std::vector<int> inversePermutationVec(size);
       for (int ind = 0; ind < size; ++ind) {
@@ -547,7 +547,7 @@ int mainFun(int argc,char* argv[]) {
       std::vector<int> perm(size);
       for (unsigned int ind = 0; ind < perm.size(); ++ind) 
 	perm[ind] = (int)ind;
-      std::random_shuffle ( perm.begin(), perm.end() );
+      mat::random_shuffle ( perm.begin(), perm.end() );
       A.assign_from_sparse(rowInd, colInd, values, rows, cols, perm, perm);
       
       std::vector<int> invPerm(size);
@@ -614,7 +614,7 @@ int mainFun(int argc,char* argv[]) {
       std::vector<int> permutationVec(size);
       for (int ind = 0; ind < size; ++ind )
 	permutationVec[ind] = ind;
-      std::random_shuffle ( permutationVec.begin(), permutationVec.end() );
+      mat::random_shuffle ( permutationVec.begin(), permutationVec.end() );
       /* Get inverse permutation */
       std::vector<int> inversePermutationVec(size);
       for (int ind = 0; ind < size; ++ind) {
