@@ -18,6 +18,7 @@ ln -s "$top_builddir_pwd"/source/ergo ./ergo
 
 if test `./ergo -e precision` = 'single'; then
     echo SKIPPED
+    cd .. ; rm -r $currtestdirname
     exit 0
 fi
 
@@ -141,6 +142,44 @@ exit 1
 fi
 
 
+echo Testing nh3[+] UBLYP/6-31G** with sparse dft turned off
+rm -f ergoscf.out
+./ergo <<EOINPUT > /dev/null
+molecule_inline Angstrom
+N      0.000000     0.000000     0.000000
+H      0.000000     0.000000     1.012316
+H      0.969771     0.000000    -0.290392
+H     -0.390071     0.887881    -0.290336
+EOF
+charge = 1
+spin_polarization = 1
+XC.sparse_mode = 0
+basis = "6-31Gss"
+run "BLYP"
+EOINPUT
+if
+check_final_energy -56.1382272 1e-5
+then
+echo OK
+else
+echo ERROR
+mv ergoscf.out $errorfilename
+echo output file saved as $errorfilename
+exit 1
+fi
+
+if
+check_final_S2 0.752002 1e-6
+then
+echo OK
+else
+echo ERROR
+mv ergoscf.out $errorfilename
+echo output file saved as $errorfilename
+exit 1
+fi
+
+
 
 cd ..
 rm -r $currtestdirname
