@@ -18,6 +18,7 @@ ln -s "$top_builddir_pwd"/source/ergo ./ergo
 
 if test `./ergo -e precision` = 'single'; then
     echo SKIPPED
+    cd .. ; rm -r $currtestdirname
     exit 0
 fi
 
@@ -96,6 +97,7 @@ mat.sparse_matrix_block_size = 1
 mat.sparse_matrix_block_factor_1 = 2
 mat.sparse_matrix_block_factor_2 = 2
 mat.sparse_matrix_block_factor_3 = 2
+scf.purification_subspace_err_limit = 1e-7
 charge = 1
 spin_polarization = 1
 set_nthreads(1)
