@@ -18,11 +18,14 @@ ln -s "$top_builddir_pwd"/source/ergo ./ergo
 
 if test `./ergo -e precision` = 'single'; then
     echo SKIPPED
+    cd .. ; rm -r $currtestdirname
     exit 0
 fi
 
 errorfilename=ergoscf.out.error.lr_pol
 
+# FIXME: in this test script, if check_pol fails somewhere the script anyway continues, does it really properly detect if the computed polarizability values are wrong?
+
 echo
 echo Testing NH3 SVWN5/4-31G polarizability
 rm -f ergoscf.out
